@@ -154,7 +154,7 @@ var _ = Describe("Generating fluentd config", func() {
     rotate_wait 5
     tag kubernetes.*
     read_from_head "true"
-    @label @CONCAT
+    @label @MEASURE
     <parse>
       @type multi_format
       <pattern>
@@ -170,7 +170,56 @@ var _ = Describe("Generating fluentd config", func() {
       </pattern>
     </parse>
   </source>
-  
+  <label @MEASURE>
+	<filter **>
+		@type record_transformer
+		enable_ruby
+		<record>
+		msg_size ${record.to_s.length}
+		</record>
+	</filter>
+	<filter **>
+		@type prometheus
+		<metric>
+		name cluster_logging_collector_input_record_total
+		type counter
+		desc The total number of incoming records
+		<labels>
+			tag ${tag}
+			hostname ${hostname}
+		</labels>
+		</metric>
+	</filter>
+	<filter **>
+		@type prometheus
+		<metric>
+		name cluster_logging_collector_input_record_bytes
+		type counter
+		desc The total bytes of incoming records
+		key msg_size
+		<labels>
+			tag ${tag}
+			hostname ${hostname}
+		</labels>
+		</metric>
+	</filter>
+	<filter **>
+		@type record_transformer
+		remove_keys msg_size
+	</filter>
+	<match journal>
+		@type relabel
+		@label @INGRESS
+	</match>
+	<match *audit.log>
+		@type relabel
+		@label @INGRESS
+	</match>
+	<match kubernetes.**>
+		@type relabel
+		@label @CONCAT
+	</match>
+	</label>  
   <label @CONCAT>
     <filter kubernetes.**>
       @type concat
@@ -471,8 +520,6 @@ var _ = Describe("Generating fluentd config", func() {
         target_index_key viaq_index_name
         id_key viaq_msg_id
         remove_keys viaq_index_name
-        user fluentd
-        password changeme
         client_key '/var/run/ocp-collector/secrets/my-es-secret/tls.key'
         client_cert '/var/run/ocp-collector/secrets/my-es-secret/tls.crt'
         ca_file '/var/run/ocp-collector/secrets/my-es-secret/ca-bundle.crt'
@@ -496,7 +543,7 @@ var _ = Describe("Generating fluentd config", func() {
           flush_at_shutdown true
           retry_type exponential_backoff
           retry_wait 1s
-          retry_max_interval 300s
+          retry_max_interval 60s
           retry_forever true
           queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
           
@@ -522,8 +569,6 @@ var _ = Describe("Generating fluentd config", func() {
         target_index_key viaq_index_name
         id_key viaq_msg_id
         remove_keys viaq_index_name
-        user fluentd
-        password changeme
         client_key '/var/run/ocp-collector/secrets/my-es-secret/tls.key'
         client_cert '/var/run/ocp-collector/secrets/my-es-secret/tls.crt'
         ca_file '/var/run/ocp-collector/secrets/my-es-secret/ca-bundle.crt'
@@ -548,7 +593,7 @@ var _ = Describe("Generating fluentd config", func() {
           flush_at_shutdown true
           retry_type exponential_backoff
           retry_wait 1s
-          retry_max_interval 300s
+          retry_max_interval 60s
           retry_forever true
           queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
           
@@ -638,7 +683,7 @@ var _ = Describe("Generating fluentd config", func() {
 				rotate_wait 5
 				tag kubernetes.*
 				read_from_head "true"
-				@label @CONCAT
+				@label @MEASURE
 				<parse>
 				@type multi_format
 				<pattern>
@@ -654,7 +699,56 @@ var _ = Describe("Generating fluentd config", func() {
 				</pattern>
 				</parse>
 			</source>
-
+			<label @MEASURE>
+				<filter **>
+				@type record_transformer
+				enable_ruby
+				<record>
+					msg_size ${record.to_s.length}
+				</record>
+				</filter>
+				<filter **>
+				@type prometheus
+				<metric>
+					name cluster_logging_collector_input_record_total
+					type counter
+					desc The total number of incoming records
+					<labels>
+					tag ${tag}
+					hostname ${hostname}
+					</labels>
+				</metric>
+				</filter>
+				<filter **>
+				@type prometheus
+				<metric>
+					name cluster_logging_collector_input_record_bytes
+					type counter
+					desc The total bytes of incoming records
+					key msg_size
+					<labels>
+					tag ${tag}
+					hostname ${hostname}
+					</labels>
+				</metric>
+				</filter>
+				<filter **>
+				@type record_transformer
+				remove_keys msg_size
+				</filter>
+				<match journal>
+				@type relabel
+				@label @INGRESS
+				</match>
+				<match *audit.log>
+				@type relabel
+				@label @INGRESS
+				</match>
+				<match kubernetes.**>
+				@type relabel
+				@label @CONCAT
+				</match>
+			</label>
 			<label @CONCAT>
 				<filter kubernetes.**>
 				@type concat
@@ -933,7 +1027,7 @@ var _ = Describe("Generating fluentd config", func() {
 					flush_thread_count 2
           retry_type exponential_backoff
           retry_wait 1s
-          retry_max_interval 300s
+          retry_max_interval 60s
 					retry_forever true
 					# the systemd journald 0.0.8 input plugin will just throw away records if the buffer
 					# queue limit is hit - 'block' will halt further reads and keep retrying to flush the
@@ -1000,7 +1094,7 @@ var _ = Describe("Generating fluentd config", func() {
 			<source>
 				@type systemd
 				@id systemd-input
-				@label @INGRESS
+				@label @MEASURE
 				path '/var/log/journal'
 				<storage>
 					@type local
@@ -1025,7 +1119,7 @@ var _ = Describe("Generating fluentd config", func() {
 				rotate_wait 5
 				tag kubernetes.*
 				read_from_head "true"
-				@label @CONCAT
+				@label @MEASURE
 				<parse>
 				@type multi_format
 				<pattern>
@@ -1046,7 +1140,7 @@ var _ = Describe("Generating fluentd config", func() {
             <source>
               @type tail
               @id audit-input
-              @label @INGRESS
+              @label @MEASURE
               path "#{ENV['AUDIT_FILE'] || '/var/log/audit/audit.log'}"
               pos_file "#{ENV['AUDIT_POS_FILE'] || '/var/log/audit/audit.log.pos'}"
               tag linux-audit.log
@@ -1059,7 +1153,7 @@ var _ = Describe("Generating fluentd config", func() {
             <source>
               @type tail
               @id k8s-audit-input
-              @label @INGRESS
+              @label @MEASURE
               path "#{ENV['K8S_AUDIT_FILE'] || '/var/log/kube-apiserver/audit.log'}"
               pos_file "#{ENV['K8S_AUDIT_POS_FILE'] || '/var/log/kube-apiserver/audit.log.pos'}"
               tag k8s-audit.log
@@ -1072,23 +1166,72 @@ var _ = Describe("Generating fluentd config", func() {
 			  </parse>
 			</source>
 
-            # Openshift audit logs
-            <source>
-              @type tail
-              @id openshift-audit-input
-              @label @INGRESS
-              path /var/log/oauth-apiserver/audit.log,/var/log/openshift-apiserver/audit.log
-              pos_file /var/log/oauth-apiserver.audit.log
-              tag openshift-audit.log
-              <parse>
-                @type json
-                time_key requestReceivedTimestamp
-                # In case folks want to parse based on the requestReceivedTimestamp key
-                keep_time_key true
-                time_format %Y-%m-%dT%H:%M:%S.%N%z
-              </parse>
-            </source>
-
+			# Openshift audit logs
+			<source>
+				@type tail
+				@id openshift-audit-input
+				@label @MEASURE
+				path /var/log/oauth-apiserver/audit.log,/var/log/openshift-apiserver/audit.log
+				pos_file /var/log/oauth-apiserver.audit.log
+				tag openshift-audit.log
+				<parse>
+				@type json
+				time_key requestReceivedTimestamp
+				# In case folks want to parse based on the requestReceivedTimestamp key
+				keep_time_key true
+				time_format %Y-%m-%dT%H:%M:%S.%N%z
+			  </parse>
+			</source>
+			<label @MEASURE>
+				<filter **>
+					@type record_transformer
+					enable_ruby
+					<record>
+					msg_size ${record.to_s.length}
+					</record>
+				</filter>
+				<filter **>
+					@type prometheus
+					<metric>
+					name cluster_logging_collector_input_record_total
+					type counter
+					desc The total number of incoming records
+					<labels>
+						tag ${tag}
+						hostname ${hostname}
+					</labels>
+					</metric>
+				</filter>
+				<filter **>
+					@type prometheus
+					<metric>
+						name cluster_logging_collector_input_record_bytes
+						type counter
+						desc The total bytes of incoming records
+						key msg_size
+						<labels>
+							tag ${tag}
+							hostname ${hostname}
+						</labels>
+				  </metric>
+				</filter>
+				<filter **>
+				  @type record_transformer
+				  remove_keys msg_size
+				</filter>
+				<match journal>
+				  @type relabel
+				  @label @INGRESS
+				</match>
+				<match *audit.log>
+				  @type relabel
+				  @label @INGRESS
+				 </match>
+				<match kubernetes.**>
+				  @type relabel
+				  @label @CONCAT
+				</match>
+			</label>
 			<label @CONCAT>
 				<filter kubernetes.**>
 				@type concat
@@ -1402,8 +1545,6 @@ var _ = Describe("Generating fluentd config", func() {
 						target_index_key viaq_index_name
 						id_key viaq_msg_id
 						remove_keys viaq_index_name
-						user fluentd
-						password changeme
 
 						client_key '/var/run/ocp-collector/secrets/my-infra-secret/tls.key'
 						client_cert '/var/run/ocp-collector/secrets/my-infra-secret/tls.crt'
@@ -1428,7 +1569,7 @@ var _ = Describe("Generating fluentd config", func() {
 							flush_at_shutdown true
               retry_type exponential_backoff
               retry_wait 1s
-              retry_max_interval 300s
+              retry_max_interval 60s
 							retry_forever true
               queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
 						  total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
@@ -1450,8 +1591,6 @@ var _ = Describe("Generating fluentd config", func() {
 						target_index_key viaq_index_name
 						id_key viaq_msg_id
 						remove_keys viaq_index_name
-						user fluentd
-						password changeme
 
 						client_key '/var/run/ocp-collector/secrets/my-infra-secret/tls.key'
 						client_cert '/var/run/ocp-collector/secrets/my-infra-secret/tls.crt'
@@ -1477,7 +1616,7 @@ var _ = Describe("Generating fluentd config", func() {
 							flush_at_shutdown true
               retry_type exponential_backoff
               retry_wait 1s
- 							retry_max_interval 300s
+ 							retry_max_interval 60s
 							retry_forever true
 							queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
 							total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
@@ -1501,8 +1640,6 @@ var _ = Describe("Generating fluentd config", func() {
 						target_index_key viaq_index_name
 						id_key viaq_msg_id
 						remove_keys viaq_index_name
-						user fluentd
-						password changeme
 
 						client_key '/var/run/ocp-collector/secrets/my-es-secret/tls.key'
 						client_cert '/var/run/ocp-collector/secrets/my-es-secret/tls.crt'
@@ -1527,7 +1664,7 @@ var _ = Describe("Generating fluentd config", func() {
 							flush_at_shutdown true
               retry_type exponential_backoff
               retry_wait 1s
-              retry_max_interval 300s
+              retry_max_interval 60s
 							retry_forever true
 							queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
 							total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
@@ -1549,8 +1686,6 @@ var _ = Describe("Generating fluentd config", func() {
 						target_index_key viaq_index_name
 						id_key viaq_msg_id
 						remove_keys viaq_index_name
-						user fluentd
-						password changeme
 
 						client_key '/var/run/ocp-collector/secrets/my-es-secret/tls.key'
 						client_cert '/var/run/ocp-collector/secrets/my-es-secret/tls.crt'
@@ -1576,7 +1711,7 @@ var _ = Describe("Generating fluentd config", func() {
 							flush_at_shutdown true
               retry_type exponential_backoff
               retry_wait 1s
-              retry_max_interval 300s
+              retry_max_interval 60s
 							retry_forever true
 							queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
 							total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
@@ -1600,8 +1735,6 @@ var _ = Describe("Generating fluentd config", func() {
 						target_index_key viaq_index_name
 						id_key viaq_msg_id
 						remove_keys viaq_index_name
-						user fluentd
-						password changeme
 
 						client_key '/var/run/ocp-collector/secrets/my-other-secret/tls.key'
 						client_cert '/var/run/ocp-collector/secrets/my-other-secret/tls.crt'
@@ -1626,7 +1759,7 @@ var _ = Describe("Generating fluentd config", func() {
 							flush_at_shutdown true
               retry_type exponential_backoff
               retry_wait 1s
-              retry_max_interval 300s
+              retry_max_interval 60s
 							retry_forever true
 							queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
 							total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
@@ -1648,8 +1781,6 @@ var _ = Describe("Generating fluentd config", func() {
 						target_index_key viaq_index_name
 						id_key viaq_msg_id
 						remove_keys viaq_index_name
-						user fluentd
-						password changeme
 
 						client_key '/var/run/ocp-collector/secrets/my-other-secret/tls.key'
 						client_cert '/var/run/ocp-collector/secrets/my-other-secret/tls.crt'
@@ -1675,7 +1806,7 @@ var _ = Describe("Generating fluentd config", func() {
 							flush_at_shutdown true
               retry_type exponential_backoff
               retry_wait 1s
-              retry_max_interval 300s
+              retry_max_interval 60s
 							retry_forever true
 							queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
 							total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
@@ -1699,8 +1830,6 @@ var _ = Describe("Generating fluentd config", func() {
 						target_index_key viaq_index_name
 						id_key viaq_msg_id
 						remove_keys viaq_index_name
-						user fluentd
-						password changeme
 
 						client_key '/var/run/ocp-collector/secrets/my-audit-secret/tls.key'
 						client_cert '/var/run/ocp-collector/secrets/my-audit-secret/tls.crt'
@@ -1725,7 +1854,7 @@ var _ = Describe("Generating fluentd config", func() {
 							flush_at_shutdown true
               retry_type exponential_backoff
               retry_wait 1s
-              retry_max_interval 300s
+              retry_max_interval 60s
 							retry_forever true
 							queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
 							total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
@@ -1747,8 +1876,6 @@ var _ = Describe("Generating fluentd config", func() {
 						target_index_key viaq_index_name
 						id_key viaq_msg_id
 						remove_keys viaq_index_name
-						user fluentd
-						password changeme
 
 						client_key '/var/run/ocp-collector/secrets/my-audit-secret/tls.key'
 						client_cert '/var/run/ocp-collector/secrets/my-audit-secret/tls.crt'
@@ -1774,7 +1901,7 @@ var _ = Describe("Generating fluentd config", func() {
 							flush_at_shutdown true
               retry_type exponential_backoff
               retry_wait 1s
-              retry_max_interval 300s
+              retry_max_interval 60s
 							retry_forever true
 							queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
 							total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
@@ -1877,7 +2004,7 @@ var _ = Describe("Generating fluentd config", func() {
       rotate_wait 5
       tag kubernetes.*
       read_from_head "true"
-      @label @CONCAT
+      @label @MEASURE
       <parse>
         @type multi_format
         <pattern>
@@ -1893,7 +2020,56 @@ var _ = Describe("Generating fluentd config", func() {
         </pattern>
       </parse>
     </source>
-    
+	<label @MEASURE>
+	<filter **>
+	  @type record_transformer
+	  enable_ruby
+	  <record>
+		msg_size ${record.to_s.length}
+	  </record>
+	</filter>
+	<filter **>
+	  @type prometheus
+	  <metric>
+		name cluster_logging_collector_input_record_total
+		type counter
+		desc The total number of incoming records
+		<labels>
+		  tag ${tag}
+		  hostname ${hostname}
+		</labels>
+	  </metric>
+	</filter>
+	<filter **>
+	  @type prometheus
+	  <metric>
+		name cluster_logging_collector_input_record_bytes
+		type counter
+		desc The total bytes of incoming records
+		key msg_size
+		<labels>
+		  tag ${tag}
+		  hostname ${hostname}
+		</labels>
+	  </metric>
+	</filter>
+	<filter **>
+	  @type record_transformer
+	  remove_keys msg_size
+	</filter>
+	<match journal>
+	  @type relabel
+	  @label @INGRESS
+	</match>
+	<match *audit.log>
+	  @type relabel
+	  @label @INGRESS
+	 </match>
+	<match kubernetes.**>
+	  @type relabel
+	  @label @CONCAT
+	</match>
+  </label>
     <label @CONCAT>
       <filter kubernetes.**>
         @type concat
