@@ -71,7 +71,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
         <source>
           @type systemd
           @id systemd-input
-          @label @INGRESS
+          @label @MEASURE
           path '/var/log/journal'
           <storage>
             @type local
@@ -95,7 +95,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
           rotate_wait 5
           tag kubernetes.*
           read_from_head "true"
-          @label @CONCAT
+          @label @MEASURE
           <parse>
             @type multi_format
             <pattern>
@@ -115,7 +115,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
         <source>
           @type tail
           @id audit-input
-          @label @INGRESS
+          @label @MEASURE
           path "#{ENV['AUDIT_FILE'] || '/var/log/audit/audit.log'}"
           pos_file "#{ENV['AUDIT_POS_FILE'] || '/var/log/audit/audit.log.pos'}"
           tag linux-audit.log
@@ -127,7 +127,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
         <source>
           @type tail
           @id k8s-audit-input
-          @label @INGRESS
+          @label @MEASURE
           path "#{ENV['K8S_AUDIT_FILE'] || '/var/log/kube-apiserver/audit.log'}"
           pos_file "#{ENV['K8S_AUDIT_POS_FILE'] || '/var/log/kube-apiserver/audit.log.pos'}"
           tag k8s-audit.log
@@ -144,7 +144,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
         <source>
           @type tail
           @id openshift-audit-input
-          @label @INGRESS
+          @label @MEASURE
           path /var/log/oauth-apiserver/audit.log,/var/log/openshift-apiserver/audit.log
           pos_file /var/log/oauth-apiserver.audit.log
           tag openshift-audit.log
@@ -156,7 +156,56 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
             time_format %Y-%m-%dT%H:%M:%S.%N%z
           </parse>
         </source>
-
+        <label @MEASURE>
+        <filter **>
+          @type record_transformer
+          enable_ruby
+          <record>
+            msg_size ${record.to_s.length}
+          </record>
+        </filter>
+        <filter **>
+          @type prometheus
+          <metric>
+            name cluster_logging_collector_input_record_total
+            type counter
+            desc The total number of incoming records
+            <labels>
+              tag ${tag}
+              hostname ${hostname}
+            </labels>
+          </metric>
+        </filter>
+        <filter **>
+          @type prometheus
+          <metric>
+            name cluster_logging_collector_input_record_bytes
+            type counter
+            desc The total bytes of incoming records
+            key msg_size
+            <labels>
+              tag ${tag}
+              hostname ${hostname}
+            </labels>
+          </metric>
+        </filter>
+        <filter **>
+          @type record_transformer
+          remove_keys msg_size
+        </filter>
+        <match journal>
+          @type relabel
+          @label @INGRESS
+        </match>
+        <match *audit.log>
+          @type relabel
+          @label @INGRESS
+         </match>
+        <match kubernetes.**>
+          @type relabel
+          @label @CONCAT
+        </match>
+      </label>
         <label @CONCAT>
           <filter kubernetes.**>
             @type concat
@@ -521,7 +570,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
         <source>
           @type systemd
           @id systemd-input
-          @label @INGRESS
+          @label @MEASURE
           path '/var/log/journal'
           <storage>
             @type local
@@ -545,7 +594,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
           rotate_wait 5
           tag kubernetes.*
           read_from_head "true"
-          @label @CONCAT
+          @label @MEASURE
           <parse>
             @type multi_format
             <pattern>
@@ -565,7 +614,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
         <source>
           @type tail
           @id audit-input
-          @label @INGRESS
+          @label @MEASURE
           path "#{ENV['AUDIT_FILE'] || '/var/log/audit/audit.log'}"
           pos_file "#{ENV['AUDIT_POS_FILE'] || '/var/log/audit/audit.log.pos'}"
           tag linux-audit.log
@@ -577,7 +626,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
         <source>
           @type tail
           @id k8s-audit-input
-          @label @INGRESS
+          @label @MEASURE
           path "#{ENV['K8S_AUDIT_FILE'] || '/var/log/kube-apiserver/audit.log'}"
           pos_file "#{ENV['K8S_AUDIT_POS_FILE'] || '/var/log/kube-apiserver/audit.log.pos'}"
           tag k8s-audit.log
@@ -594,7 +643,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
         <source>
           @type tail
           @id openshift-audit-input
-          @label @INGRESS
+          @label @MEASURE
           path /var/log/oauth-apiserver/audit.log,/var/log/openshift-apiserver/audit.log
           pos_file /var/log/oauth-apiserver.audit.log
           tag openshift-audit.log
@@ -606,7 +655,56 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
             time_format %Y-%m-%dT%H:%M:%S.%N%z
           </parse>
         </source>
-
+        <label @MEASURE>
+        <filter **>
+          @type record_transformer
+          enable_ruby
+          <record>
+            msg_size ${record.to_s.length}
+          </record>
+        </filter>
+        <filter **>
+          @type prometheus
+          <metric>
+            name cluster_logging_collector_input_record_total
+            type counter
+            desc The total number of incoming records
+            <labels>
+              tag ${tag}
+              hostname ${hostname}
+            </labels>
+          </metric>
+        </filter>
+        <filter **>
+          @type prometheus
+          <metric>
+            name cluster_logging_collector_input_record_bytes
+            type counter
+            desc The total bytes of incoming records
+            key msg_size
+            <labels>
+              tag ${tag}
+              hostname ${hostname}
+            </labels>
+          </metric>
+        </filter>
+        <filter **>
+          @type record_transformer
+          remove_keys msg_size
+        </filter>
+        <match journal>
+          @type relabel
+          @label @INGRESS
+        </match>
+        <match *audit.log>
+          @type relabel
+          @label @INGRESS
+         </match>
+        <match kubernetes.**>
+          @type relabel
+          @label @CONCAT
+        </match>
+      </label>
         <label @CONCAT>
           <filter kubernetes.**>
             @type concat
@@ -973,7 +1071,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
         <source>
           @type systemd
           @id systemd-input
-          @label @INGRESS
+          @label @MEASURE
           path '/var/log/journal'
           <storage>
             @type local
@@ -997,7 +1095,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
           rotate_wait 5
           tag kubernetes.*
           read_from_head "true"
-          @label @CONCAT
+          @label @MEASURE
           <parse>
             @type multi_format
             <pattern>
@@ -1017,7 +1115,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
         <source>
           @type tail
           @id audit-input
-          @label @INGRESS
+          @label @MEASURE
           path "#{ENV['AUDIT_FILE'] || '/var/log/audit/audit.log'}"
           pos_file "#{ENV['AUDIT_POS_FILE'] || '/var/log/audit/audit.log.pos'}"
           tag linux-audit.log
@@ -1029,7 +1127,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
         <source>
           @type tail
           @id k8s-audit-input
-          @label @INGRESS
+          @label @MEASURE
           path "#{ENV['K8S_AUDIT_FILE'] || '/var/log/kube-apiserver/audit.log'}"
           pos_file "#{ENV['K8S_AUDIT_POS_FILE'] || '/var/log/kube-apiserver/audit.log.pos'}"
           tag k8s-audit.log
@@ -1046,7 +1144,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
         <source>
           @type tail
           @id openshift-audit-input
-          @label @INGRESS
+          @label @MEASURE
           path /var/log/oauth-apiserver/audit.log,/var/log/openshift-apiserver/audit.log
           pos_file /var/log/oauth-apiserver.audit.log
           tag openshift-audit.log
@@ -1058,7 +1156,56 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
             time_format %Y-%m-%dT%H:%M:%S.%N%z
           </parse>
         </source>
-
+        <label @MEASURE>
+        <filter **>
+          @type record_transformer
+          enable_ruby
+          <record>
+            msg_size ${record.to_s.length}
+          </record>
+        </filter>
+        <filter **>
+          @type prometheus
+          <metric>
+            name cluster_logging_collector_input_record_total
+            type counter
+            desc The total number of incoming records
+            <labels>
+              tag ${tag}
+              hostname ${hostname}
+            </labels>
+          </metric>
+        </filter>
+        <filter **>
+          @type prometheus
+          <metric>
+            name cluster_logging_collector_input_record_bytes
+            type counter
+            desc The total bytes of incoming records
+            key msg_size
+            <labels>
+              tag ${tag}
+              hostname ${hostname}
+            </labels>
+          </metric>
+        </filter>
+        <filter **>
+          @type record_transformer
+          remove_keys msg_size
+        </filter>
+        <match journal>
+          @type relabel
+          @label @INGRESS
+        </match>
+        <match *audit.log>
+          @type relabel
+          @label @INGRESS
+         </match>
+        <match kubernetes.**>
+          @type relabel
+          @label @CONCAT
+        </match>
+      </label>
         <label @CONCAT>
           <filter kubernetes.**>
             @type concat
