@@ -72,8 +72,6 @@ var _ = Describe("Generating fluentd config", func() {
               target_index_key viaq_index_name
               id_key viaq_msg_id
               remove_keys viaq_index_name
-              user fluentd
-              password changeme
 
               type_name _doc
               http_backend typhoeus
@@ -95,7 +93,7 @@ var _ = Describe("Generating fluentd config", func() {
                 flush_at_shutdown true
                 retry_type exponential_backoff
                 retry_wait 1s
-                retry_max_interval 300s
+                retry_max_interval 60s
                 retry_forever true
                 queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
                 total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
@@ -116,8 +114,6 @@ var _ = Describe("Generating fluentd config", func() {
               target_index_key viaq_index_name
               id_key viaq_msg_id
               remove_keys viaq_index_name
-              user fluentd
-              password changeme
 
               type_name _doc
               retry_tag retry_other_elasticsearch
@@ -140,7 +136,7 @@ var _ = Describe("Generating fluentd config", func() {
                 flush_at_shutdown true
                 retry_type exponential_backoff
                 retry_wait 1s
-                retry_max_interval 300s
+                retry_max_interval 60s
                 retry_forever true
                 queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
                 total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
@@ -189,8 +185,6 @@ var _ = Describe("Generating fluentd config", func() {
               target_index_key viaq_index_name
               id_key viaq_msg_id
               remove_keys viaq_index_name
-              user fluentd
-              password changeme
 
               type_name _doc
               http_backend typhoeus
@@ -212,7 +206,7 @@ var _ = Describe("Generating fluentd config", func() {
                 flush_at_shutdown true
                 retry_type exponential_backoff
                 retry_wait 1s
-                retry_max_interval 300s
+                retry_max_interval 60s
                 retry_forever true
                 queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
                 total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
@@ -233,8 +227,6 @@ var _ = Describe("Generating fluentd config", func() {
               target_index_key viaq_index_name
               id_key viaq_msg_id
               remove_keys viaq_index_name
-              user fluentd
-              password changeme
 
               type_name _doc
               retry_tag retry_other_elasticsearch
@@ -257,7 +249,7 @@ var _ = Describe("Generating fluentd config", func() {
                 flush_at_shutdown true
                 retry_type exponential_backoff
                 retry_wait 1s
-                retry_max_interval 300s
+                retry_max_interval 60s
                 retry_forever true
                 queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
                 total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
@@ -289,8 +281,6 @@ var _ = Describe("Generating fluentd config", func() {
               target_index_key viaq_index_name
               id_key viaq_msg_id
               remove_keys viaq_index_name
-              user fluentd
-              password changeme
 
               type_name _doc
               http_backend typhoeus
@@ -333,8 +323,6 @@ var _ = Describe("Generating fluentd config", func() {
               target_index_key viaq_index_name
               id_key viaq_msg_id
               remove_keys viaq_index_name
-              user fluentd
-              password changeme
 
               type_name _doc
               retry_tag retry_other_elasticsearch
@@ -410,7 +398,7 @@ var _ = Describe("Generating fluentd config", func() {
             flush_thread_count 2
             retry_type exponential_backoff
             retry_wait 1s
-            retry_max_interval 300s
+            retry_max_interval 60s
             retry_forever true
             # the systemd journald 0.0.8 input plugin will just throw away records if the buffer
             # queue limit is hit - 'block' will halt further reads and keep retrying to flush the
@@ -524,7 +512,7 @@ var _ = Describe("Generating fluentd config", func() {
                 flush_at_shutdown true
                 retry_type exponential_backoff
                 retry_wait 1s
-                retry_max_interval 300s
+                retry_max_interval 60s
                 retry_forever true
                 queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
                 total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
@@ -630,7 +618,7 @@ var _ = Describe("Generating fluentd config", func() {
                flush_at_shutdown true
                retry_type exponential_backoff
                retry_wait 1s
-               retry_max_interval 300s
+               retry_max_interval 60s
                retry_forever true
                queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
                total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
